pub struct ParseError;Expand description
Error returned by <NHSNumber as FromStr>::from_str for any string
that is not one of the two accepted shapes (see spec.md 5).
ParseError is a unit struct — every error value compares equal:
use nhs_number::NHSNumber;
use nhs_number::parse_error::ParseError;
use std::str::FromStr;
let a = NHSNumber::from_str("not even close").unwrap_err();
let b = NHSNumber::from_str("wrong length").unwrap_err();
assert_eq!(a, b);
assert_eq!(a, ParseError);To map it to your own richer error type:
use nhs_number::NHSNumber;
use std::str::FromStr;
#[derive(Debug, PartialEq)]
enum MyError {
BadNhsNumber(String),
}
let bad = "not a number";
let result: Result<NHSNumber, MyError> =
NHSNumber::from_str(bad).map_err(|_| MyError::BadNhsNumber(bad.into()));
assert_eq!(result, Err(MyError::BadNhsNumber("not a number".into())));Trait Implementations
Sourceimpl Debug for ParseError
impl Debug for ParseError
impl Eq for ParseError
Sourceimpl PartialEq for ParseError
impl PartialEq for ParseError
Sourcefn eq(&self, other: &ParseError) -> bool
fn eq(&self, other: &ParseError) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ParseError